require 'objects.lua'

-- slight adaption of the example given in the wiki ...
  -- who wrote that, BTW? I'd like to give credit where it's due
function newPaddedImage(filename)
  local source=love.image.newImageData(filename)
  local w,h=source:getWidth(),source:getHeight()
  local paddedData={}
  -- Find closest power-of-two.
  local wp=math.pow(2,math.ceil(math.log(w)/math.log(2)))
  local hp=math.pow(2,math.ceil(math.log(h)/math.log(2)))
  -- Only pad if needed:
  if wp~=w or hp~=h then
    local padded=love.image.newImageData(wp,hp)
    padded:paste(source,0,0)
    paddedData.image=love.graphics.newImage(padded)
  else paddedData.image=love.graphics.newImage(source)
  end
  paddedData.w=w
  paddedData.h=h
  return paddedData
end

function getMidpoint(x,y,w,h) return math.floor(x+(w/2)),math.floor(y+(h/2)) end

function getDistance(x1,y1,x2,y2) return math.sqrt(((x1-x2)^2)+((y1-y2)^2)) end

function love.load()
  -- seed the random() function with the OS time so we don't get the same results every time
  math.randomseed(os.time())
  -- pop the first few numbers; some systems have a problem generating them
  for i=1,5 do math.random() end
  gamefont=love.graphics.newImageFont('/img/misc/font.png'," ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890%:!?+-=*/,';()\"$#.\\")
  loadObjects()
  for i=1,#objectlist do objectlist[i]:load() objectlist[i]:init() end
  
  alertsound=love.audio.newSource("/snd/alert.ogg","static")
  alertsound:setVolume(0.75) -- was 0.25
  bgmusic=love.audio.newSource("/snd/Bored No. 2.ogg","stream")
  bgmusic:play()
  paused=false
  
end

function love.keypressed(k)
  if not paused then
    if k=="r" then
      for i=1,#objectlist do objectlist[i]:load() objectlist[i]:init() end
    end
    if k=="p" then paused=true bgmusic:pause() end
  else paused=false bgmusic:resume() end
end

function love.draw()
    for i=1,#objectlist do objectlist[i]:draw() end
end

function love.update(dt)
  if not paused then
    for i=1,#objectlist do objectlist[i]:update(dt) end
    if bgmusic:isStopped() then bgmusic:play() end
  end
end